EdgeWeighting
=============

.. currentmodule:: pykeen.nn.weighting

.. autoclass:: EdgeWeighting
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~EdgeWeighting.forward

   .. rubric:: Methods Documentation

   .. automethod:: forward
